<?php
defined('TYPO3_MODE') || die('Access denied.');

call_user_func(
    function()
    {

        \TYPO3\CMS\Extbase\Utility\ExtensionUtility::registerPlugin(
            'SG.BlogSgEnhancements',
            'Blogfeaturedpost',
            'Blog: Featured Post'
        );

        \TYPO3\CMS\Extbase\Utility\ExtensionUtility::registerPlugin(
            'SG.BlogSgEnhancements',
            'Bloglistposts',
            'Blog: List Posts'
        );

        \TYPO3\CMS\Extbase\Utility\ExtensionUtility::registerPlugin(
            'SG.BlogSgEnhancements',
            'Blogcuratedposts',
            'Blog: Curated Posts'
        );

        \TYPO3\CMS\Extbase\Utility\ExtensionUtility::registerPlugin(
            'SG.BlogSgEnhancements',
            'Bloglistcategories',
            'Blog: List Categories'
        );

        \TYPO3\CMS\Extbase\Utility\ExtensionUtility::registerPlugin(
            'SG.BlogSgEnhancements',
            'BlogHeader',
            'Blog: Header'
        );

//        \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::addStaticFile('blog_sg_enhancements', 'Configuration/TypoScript', 'Blog sg.enhancements');

    }
);
